@@ -1,10 +1,12 @@
 #!/usr/bin/env python
 import re
 from collections.abc import MutableMapping, Iterable
-from ordered_set import OrderedSet
+from deepdiff.helper import OrderedSetPlus
 import logging
 
-from deepdiff.helper import strings, numbers, add_to_frozen_set, get_doc, dict_
+from deepdiff.helper import (
+    strings, numbers, add_to_frozen_set, get_doc, dict_, RE_COMPILED_TYPE
+)
 
 logger = logging.getLogger(__name__)
 
@@ -40,6 +42,8 @@ class DeepSearch(dict):
         If True, the value of the object or its children have to exactly match the item.
         If False, the value of the item can be a part of the value of the object or its children
 
+    use_regexp: Boolean, default = False
+
     **Returns**
 
         A DeepSearch object that has the matched paths and matched values.
@@ -77,12 +81,13 @@ class DeepSearch(dict):
     def __init__(self,
                  obj,
                  item,
-                 exclude_paths=OrderedSet(),
-                 exclude_regex_paths=OrderedSet(),
-                 exclude_types=OrderedSet(),
+                 exclude_paths=OrderedSetPlus(),
+                 exclude_regex_paths=OrderedSetPlus(),
+                 exclude_types=OrderedSetPlus(),
                  verbose_level=1,
                  case_sensitive=False,
                  match_string=False,
+                 use_regexp=False,
                  **kwargs):
         if kwargs:
             raise ValueError((
@@ -94,9 +99,9 @@ class DeepSearch(dict):
         self.obj = obj
         self.case_sensitive = case_sensitive if isinstance(item, strings) else True
         item = item if self.case_sensitive else item.lower()
-        self.exclude_paths = OrderedSet(exclude_paths)
+        self.exclude_paths = OrderedSetPlus(exclude_paths)
         self.exclude_regex_paths = [re.compile(exclude_regex_path) for exclude_regex_path in exclude_regex_paths]
-        self.exclude_types = OrderedSet(exclude_types)
+        self.exclude_types = OrderedSetPlus(exclude_types)
         self.exclude_types_tuple = tuple(
             exclude_types)  # we need tuple for checking isinstance
         self.verbose_level = verbose_level
@@ -104,6 +109,9 @@ class DeepSearch(dict):
             matched_paths=self.__set_or_dict(),
             matched_values=self.__set_or_dict(),
             unprocessed=[])
+        self.use_regexp = use_regexp
+        if self.use_regexp:
+            item = re.compile(item)
 
         # Cases where user wants to match exact string item
         self.match_string = match_string
@@ -116,7 +124,7 @@ class DeepSearch(dict):
             del self[k]
 
     def __set_or_dict(self):
-        return dict_() if self.verbose_level >= 2 else OrderedSet()
+        return dict_() if self.verbose_level >= 2 else OrderedSetPlus()
 
     def __report(self, report_key, key, value):
         if self.verbose_level >= 2:
@@ -135,7 +143,7 @@ class DeepSearch(dict):
         if obj == item:
             found = True
             # We report the match but also continue inside the match to see if there are
-            # furthur matches inside the `looped` object.
+            # further matches inside the `looped` object.
             self.__report(report_key='matched_values', key=parent, value=obj)
 
         try:
@@ -183,7 +191,7 @@ class DeepSearch(dict):
         else:
             parent_text = "%s[%s]"
 
-        obj_keys = OrderedSet(obj.keys())
+        obj_keys = OrderedSetPlus(obj.keys())
 
         for item_key in obj_keys:
             if not print_as_attribute and isinstance(item_key, strings):
@@ -205,7 +213,8 @@ class DeepSearch(dict):
 
             str_item = str(item)
             if (self.match_string and str_item == new_parent_cased) or\
-               (not self.match_string and str_item in new_parent_cased):
+               (not self.match_string and str_item in new_parent_cased) or\
+               (self.use_regexp and item.search(new_parent_cased)):
                 self.__report(
                     report_key='matched_paths',
                     key=new_parent,
@@ -223,7 +232,6 @@ class DeepSearch(dict):
                           parent="root",
                           parents_ids=frozenset()):
         """Search iterables except dictionaries, sets and strings."""
-
         for i, thing in enumerate(obj):
             new_parent = "{}[{}]".format(parent, i)
             if self.__skip_this(thing, parent=new_parent):
@@ -234,7 +242,7 @@ class DeepSearch(dict):
             else:
                 thing_cased = thing.lower()
 
-            if thing_cased == item:
+            if not self.use_regexp and thing_cased == item:
                 self.__report(
                     report_key='matched_values', key=new_parent, value=thing)
             else:
@@ -249,7 +257,12 @@ class DeepSearch(dict):
         """Compare strings"""
         obj_text = obj if self.case_sensitive else obj.lower()
 
-        if (self.match_string and item == obj_text) or (not self.match_string and item in obj_text):
+        is_matched = False
+        if self.use_regexp:
+            is_matched = item.search(obj_text)
+        elif (self.match_string and item == obj_text) or (not self.match_string and item in obj_text):
+            is_matched = True
+        if is_matched:
             self.__report(report_key='matched_values', key=parent, value=obj)
 
     def __search_numbers(self, obj, item, parent):
@@ -271,11 +284,10 @@ class DeepSearch(dict):
 
     def __search(self, obj, item, parent="root", parents_ids=frozenset()):
         """The main search method"""
-
         if self.__skip_this(item, parent):
             return
 
-        elif isinstance(obj, strings) and isinstance(item, strings):
+        elif isinstance(obj, strings) and isinstance(item, (strings, RE_COMPILED_TYPE)):
             self.__search_str(obj, item, parent)
 
         elif isinstance(obj, strings) and isinstance(item, numbers):
@@ -299,7 +311,7 @@ class DeepSearch(dict):
                 self.warning_num += 1
             self.__search_iterable(obj, item, parent, parents_ids)
 
-        elif isinstance(obj, Iterable):
+        elif isinstance(obj, Iterable) and not isinstance(obj, strings):
             self.__search_iterable(obj, item, parent, parents_ids)
 
         else:
